@@ -61,7 +61,7 @@ auto_test <- function(code_path, test_path, reporter = "summary", env = NULL) {
     } else if (length(tests) > 0) {
       # If test changes, rerun just that test
       cat("Rerunning tests: ", str_c(basename(tests), collapse = ", "), "\n")      
-      with_reporter(reporter$clone(), lapply(tests, sys.source, 
+      with_reporter(reporter$new(), lapply(tests, sys.source, 
         env = new.env(parent = env), chdir = TRUE))
     }
     
